@@ -33,10 +33,8 @@ class AnalyticsClient(object):
         client = AnalyticsClient(transporter, config)
 
         if is_async_available():
-            from algoliasearch.analytics_client_async import \
-                AnalyticsClientAsync
-            from algoliasearch.http.transporter_async import \
-                TransporterAsync
+            from algoliasearch.analytics_client_async import AnalyticsClientAsync
+            from algoliasearch.http.transporter_async import TransporterAsync
             from algoliasearch.http.requester_async import RequesterAsync
 
             return AnalyticsClientAsync(
@@ -48,57 +46,38 @@ class AnalyticsClient(object):
     def get_ab_tests(self, request_options=None):
         # type: (Optional[Union[Dict[str, Any], RequestOptions]]) -> dict
 
-        return self._transporter.read(
-            Verb.GET,
-            '2/abtests',
-            None,
-            request_options
-        )
+        return self._transporter.read(Verb.GET, "2/abtests", None, request_options)
 
     def get_ab_test(self, ab_test_id, request_options=None):
         # type: (str, Optional[Union[Dict[str, Any], RequestOptions]]) -> dict
 
-        assert ab_test_id, 'ab_test_id cannot be empty.'
+        assert ab_test_id, "ab_test_id cannot be empty."
 
         return self._transporter.read(
-            Verb.GET,
-            endpoint('2/abtests/{}', ab_test_id),
-            None,
-            request_options
+            Verb.GET, endpoint("2/abtests/{}", ab_test_id), None, request_options
         )
 
     def add_ab_test(self, ab_test, request_options=None):
         # type: (dict, Optional[Union[Dict[str, Any], RequestOptions]]) -> dict
 
-        return self._transporter.write(
-            Verb.POST,
-            '2/abtests',
-            ab_test,
-            request_options
-        )
+        return self._transporter.write(Verb.POST, "2/abtests", ab_test, request_options)
 
     def stop_ab_test(self, ab_test_id, request_options=None):
         # type: (int, Optional[Union[Dict[str, Any], RequestOptions]]) -> dict
 
-        assert ab_test_id, 'ab_test_id cannot be empty.'
+        assert ab_test_id, "ab_test_id cannot be empty."
 
         return self._transporter.write(
-            Verb.POST,
-            endpoint('2/abtests/{}/stop', ab_test_id),
-            None,
-            request_options
+            Verb.POST, endpoint("2/abtests/{}/stop", ab_test_id), None, request_options
         )
 
     def delete_ab_test(self, ab_test_id, request_options=None):
         # type: (int, Optional[Union[Dict[str, Any], RequestOptions]]) -> dict
 
-        assert ab_test_id, 'ab_test_id cannot be empty.'
+        assert ab_test_id, "ab_test_id cannot be empty."
 
         return self._transporter.write(
-            Verb.DELETE,
-            endpoint('2/abtests/{}', ab_test_id),
-            None,
-            request_options
+            Verb.DELETE, endpoint("2/abtests/{}", ab_test_id), None, request_options
         )
 
     def close(self):
