@@ -15,8 +15,7 @@ class RecommendationClientAsync(RecommendationClient):
         self._transporter_async = transporter
 
         super(RecommendationClientAsync, self).__init__(
-            recommendation_client._transporter,
-            search_config
+            recommendation_client._transporter, search_config
         )
 
         client = RecommendationClient(transporter, search_config)
