@@ -11,7 +11,6 @@ from algoliasearch.search_index_async import SearchIndexAsync
 
 
 class SearchClientAsync(SearchClient):
-
     def __init__(self, search_client, transporter, search_config):
         # type: (SearchClient, TransporterAsync, SearchConfig) -> None
 
@@ -19,13 +18,12 @@ class SearchClientAsync(SearchClient):
         self._transporter_async = transporter
 
         super(SearchClientAsync, self).__init__(
-            search_client._transporter,
-            search_config
+            search_client._transporter, search_config
         )
 
         search_client = SearchClient(transporter, search_config)
-        search_client.__setattr__('init_index', self.init_index)
-        search_client.__setattr__('_sync', self._sync)
+        search_client.__setattr__("init_index", self.init_index)
+        search_client.__setattr__("_sync", self._sync)
         _create_async_methods_in(self, search_client)
 
     def init_index(self, name):
@@ -33,8 +31,7 @@ class SearchClientAsync(SearchClient):
 
         index = self._search_client.init_index(name)
 
-        return SearchIndexAsync(
-            index, self._transporter_async, self._config, name)
+        return SearchIndexAsync(index, self._transporter_async, self._config, name)
 
     @asyncio.coroutine
     def __aenter__(self):
